@@ -204,7 +204,6 @@ def get_unit_by_imei(imei: str, session: WialonSession) -> WialonUnit | None:
     :param session: A valid Wialon API session.
     :type session: :py:obj:`~terminusgps.wialon.session.WialonSession`
     :raises ValueError: If ``imei`` contains non-digit characters.
-    :raises WialonError: If something goes wrong during a Wialon API call.
     :returns: A Wialon object id, if it was found.
     :rtype: :py:obj:`str` | :py:obj:`None`
 
@@ -217,23 +216,23 @@ def get_unit_by_imei(imei: str, session: WialonSession) -> WialonUnit | None:
             "spec": {
                 "itemsType": "avl_unit",
                 "propName": "sys_unique_id",
-                "propValueMask": f"*{imei}*",
+                "propValueMask": imei,
                 "sortType": "sys_unique_id",
                 "propType": "property",
                 "or_logic": 0,
             },
             "force": 0,
-            "flags": flags.DataFlag.UNIT_BASE.value,
+            "flags": flags.DataFlag.UNIT_BASE,
             "from": 0,
             "to": 0,
         }
     )
 
-    if results and results.get("totalItemsCount", 0) == 1:
+    if results is not None and results.get("totalItemsCount", 0) == 1:
         return WialonUnit(id=results["items"][0].get("id"), session=session)
 
 
-def get_vin_info(vin_number: str, session: WialonSession) -> dict:
+def get_vin_info(vin_number: str, session: WialonSession) -> dict[str, typing.Any]:
     """
     Retrieves vehicle data from a VIN number.
 
@@ -294,9 +293,9 @@ def generate_wialon_password(length: int = 32) -> str:
         - At least one special symbol.
         - At least three digits.
 
-    :param length: Length of the generated password. Default is ``32``.
+    :param length: Length of the generated password. Default is :py:obj:`32`.
     :type length: :py:obj:`int`
-    :raises ValueError: If :py:length is less than ``8`` or greater than ``64``.
+    :raises ValueError: If ``length`` is less than ``8`` or greater than ``64``.
     :returns: A Wialon compliant password.
     :rtype: :py:obj:`str`
 
